from django.contrib import admin
from django.utils.html import format_html
from django.utils.translation import ugettext_lazy as _

from ..models.exercise_type import ExerciseType, ExerciseTypeImage, ExerciseTypeTranslation, ExerciseTypeAlternative, \
                                    ExerciseTypeParents, ExerciseTypeDevice


class ExerciseTypeDeviceInline(admin.StackedInline):
    model = ExerciseTypeDevice
    extra = 0
    fields = ["exercise_type", "exercise_device"]


class ImageInline(admin.StackedInline):
    model = ExerciseTypeImage
    extra = 0
    fields = ["name", "url", "type", "get_image_preview"]
    readonly_fields = ("get_image_preview",)

    def get_image_preview(self, obj):
        image_url = '/media/' + str(obj.url)
        if obj.pk:
            return format_html('<img src="{url}" title="{url}" width="30%" height="30%"/> ' \
                               .format(url=image_url))

    get_image_preview.short_description = _("Image Preview")


class TranslationInline(admin.TabularInline):
    model = ExerciseTypeTranslation
    fields = ('language_code', 'name', 'description')
    extra = 0


class ExerciseTypeAlternativesInline(admin.TabularInline):
    model = ExerciseTypeAlternative
    fk_name = 'exercise_type_child'
    fields = ('exercise_type_parent',)
    extra = 0


class ExerciseTypeParentsInline(admin.TabularInline):
    model = ExerciseTypeParents
    fields = ('exercise_tree',)
    extra = 0


class ExerciseTypeAdmin(admin.ModelAdmin):
    list_display = ('exercise_type_id', 'name_colored', 'active', 'base')
    search_fields = ['name', 'exercisetypetranslation__name']
    fields = ('name', 'description', 'unit', 'unit_quantity', 'unit_quantity_unit', 'active', 'base')

    def name_colored(self, obj):
        if obj.active:
            if obj.base:
                color_code = '7bc863'
            else:
                color_code = '4178bc'
        else:
            color_code = 'C20000'
        html = '<span style="color: #{};">{}</span>˓→'.format(color_code, obj.name)
        return format_html(html)

    name_colored.admin_order_field = 'name'
    name_colored.short_description = 'name'

    inlines = [
        ImageInline,
        TranslationInline,
        ExerciseTypeDeviceInline,
        ExerciseTypeAlternativesInline,
        ExerciseTypeParentsInline
    ]
    exclude = ('exercise_tree',)


admin.site.register(ExerciseType, ExerciseTypeAdmin)
admin.autodiscover()
