from django.db import models
from django.utils.translation import ugettext_lazy as _
from ckeditor.fields import RichTextField

from .enums import LanguageTypes
from .exercise_type import ExerciseType


class TemplateTypes(models.TextChoices):
    MINI_SET = "mini_test_set"
    SPECIAL = "special"


class ExercisePlanTemplate(models.Model):
    exercise_plan_template_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=100, help_text='The name should be in English here')
    description = RichTextField()
    template_type = models.CharField(max_length=20, choices=TemplateTypes.choices, default=TemplateTypes.SPECIAL)

    class Meta:
        db_table = 'exercise_plan_template'
        verbose_name = _("Exercise Plan Template")
        verbose_name_plural = _("Exercise Plan Templates")

    def __str__(self):
        return self.name


class ExercisePlanTemplateTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    exercise_plan_template = models.ForeignKey(ExercisePlanTemplate, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    name = models.CharField(max_length=100)
    description = RichTextField(blank=True, null=True)

    class Meta:
        db_table = 'exercise_plan_template_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")

    def __str__(self):
        return self.name


class ExercisePlanTemplateDetail(models.Model):
    exercise_plan_template_detail_id = models.AutoField(primary_key=True)
    exercise_plan_template = models.ForeignKey(ExercisePlanTemplate, on_delete=models.CASCADE)
    exercise_type = models.ForeignKey(ExerciseType, on_delete=models.CASCADE)
    serie = models.IntegerField()
    quantity = models.FloatField()
    quantity_unit_quantity = models.FloatField()
    resting_time = models.TimeField()
    sort = models.IntegerField()

    class Meta:
        db_table = 'exercise_plan_template_detail'
        verbose_name = _("Exercise Plan Template Detail")
        verbose_name_plural = _("Exercise Plan Template Details")
