from django.db import models
from django.utils.translation import ugettext_lazy as _
from .enums import LanguageTypes


class ExerciseTree(models.Model):
    tree_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=100, help_text='The name should be in English here')
    description = models.TextField(max_length=1000, blank=True, null=True, help_text='The description should be in '
                                                                                     'English here')
    image_url = models.ImageField(upload_to='images/', help_text='The menu image size is 1366x768')
    active = models.BooleanField(default=0, blank=True, null=True)

    class Meta:
        db_table = 'exercise_tree'
        verbose_name = _("Exercise Tree")
        verbose_name_plural = _("Exercise Tree Items")
        ordering = ['name']

    def __str__(self):
        return self.name


class ExerciseTreeTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    tree = models.ForeignKey(ExerciseTree, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    name = models.CharField(max_length=100)
    description = models.TextField(max_length=1000, blank=True, null=True)

    class Meta:
        db_table = 'exercise_tree_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")

    def __str__(self):
        return self.name


class ExerciseTreeParents(models.Model):
    # treenode_display_field = 'name'
    exercise_tree_parents_id = models.AutoField(primary_key=True)
    exercise_tree_parent = models.ForeignKey(ExerciseTree, on_delete=models.CASCADE,
                                             related_name='exercise_tree_parent',
                                             help_text=_('Parent menu'), blank=True)
    exercise_tree_child = models.ForeignKey(ExerciseTree, on_delete=models.CASCADE)

    class Meta:
        db_table = 'exercise_tree_parents'
        verbose_name = _("Menu Tree Representation")
        verbose_name_plural = _("Menu Tree Representation")
        unique_together = [['exercise_tree_parent', 'exercise_tree_child']]
        app_label = 'aitrainer_backoffice.aitrainer_backoffice'
