from django.db import models
from django.utils.translation import ugettext_lazy as _
from ckeditor.fields import RichTextField

from .enums import LanguageTypes


class Faq(models.Model):
    faq_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=50, help_text='Unique description name',
                            verbose_name=_("name"))
    description = RichTextField()

    class Meta:
        db_table = 'faq'
        verbose_name = _("FAQ")
        verbose_name_plural = _("FAQs")

    def __str__(self):
        return self.name


class FaqTranslation(models.Model):
    faq_translation_id = models.AutoField(primary_key=True)
    faq = models.ForeignKey(Faq, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    name_translation = RichTextField()
    description_translation = RichTextField()

    class Meta:
        db_table = 'faq_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")
