from ckeditor.fields import RichTextField
from django.db import models
from django.utils.translation import ugettext_lazy as _

from .enums import LanguageTypes
from ..models import ExerciseType


class TrainingPlan(models.Model):
    training_plan_id = models.AutoField(primary_key=True)
    name = models.CharField(max_length=100, help_text='The name of the training plan',
                            verbose_name=_("name"))
    description = RichTextField(blank=True, null=True)

    class Meta:
        db_table = 'training_plan'
        verbose_name = _("Training Plan")
        verbose_name_plural = _("Training Plans")

    def __str__(self):
        return self.name


class TrainingPlanDetail(models.Model):
    training_plan_detail_id = models.AutoField(primary_key=True)
    training_plan = models.ForeignKey(TrainingPlan, on_delete=models.CASCADE)
    exercise_type = models.ForeignKey(ExerciseType, on_delete=models.CASCADE)
    sort = models.IntegerField()
    set = models.IntegerField()
    repeats = models.IntegerField(blank=True)
    weight = models.IntegerField(blank=True)
    resting_time = models.IntegerField(blank=True)
    parallel = models.BooleanField(blank=True)
    day = models.CharField(max_length=50, blank=True)

    class Meta:
        db_table = 'training_plan_detail'
        verbose_name = _("Training Plan Detail")
        verbose_name_plural = _("Training Plan Details")


class TrainingPlanTranslation(models.Model):
    translation_id = models.AutoField(primary_key=True)
    training_plan = models.ForeignKey(TrainingPlan, on_delete=models.CASCADE)
    language_code = models.CharField(max_length=2, choices=LanguageTypes.choices, default=LanguageTypes.HU)
    name_translation = models.CharField(max_length=50)
    description_translation = RichTextField(blank=True, null=True)

    class Meta:
        db_table = 'training_plan_translation'
        verbose_name = _("Translation")
        verbose_name_plural = _("Translations")

    def __str__(self):
        return self.name_translation
